==> oct8ne-v.1.3.0.zip: oct8ne/translations/es.php <==
<?php

global $_MODULE;
$_MODULE = [];
$_MODULE['<{oct8ne}prestashop>oct8ne_bc741b828f1fc35a6f10c870d6056343'] = 'Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_0789d0fc306910674ed5bcfaae62daa6'] = 'Conector del módulo Oct8ne para Prestashop';
$_MODULE['<{oct8ne}prestashop>oct8ne_a9390206b02d5d06ee405aa6b4d7b232'] = 'Todos los datos se borrarán ¿Desea continuar?';
$_MODULE['<{oct8ne}prestashop>oct8ne_98570a32ff932f557a4d0e1bdc60a790'] = 'Actualizaciones del módulo Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_b29020b008aa798ee00dc4824f780d8b'] = 'Notificar cuando haya una nueva versión disponible';
$_MODULE['<{oct8ne}prestashop>oct8ne_bfd224a1eea1e60be99a6fc9b55bf016'] = 'Habilitar o deshabilitar las notificaciones de actualización en el administrador de módulos.';
$_MODULE['<{oct8ne}prestashop>oct8ne_00d23a76e43b46dae9ec7aa9dcbebb32'] = 'Habilitado';
$_MODULE['<{oct8ne}prestashop>oct8ne_b9f5c797ebbf55adccdd8539a65a0241'] = 'Deshabilitado';
$_MODULE['<{oct8ne}prestashop>oct8ne_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{oct8ne}prestashop>oct8ne_004b04925fa8a42d0d28c3862c6947bd'] = 'Identificación incorrecta, por favor, comprueba tus credenciales';
$_MODULE['<{oct8ne}prestashop>oct8ne_5f2faa4c7bc8b0d9862218f744a1aee3'] = 'Configuración de oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{oct8ne}prestashop>oct8ne_3d236caa22b35b852d3d9f402ecd361d'] = 'Su email...';
$_MODULE['<{oct8ne}prestashop>oct8ne_dc647eb65e6711e155375218212b3964'] = 'Contraseña';
$_MODULE['<{oct8ne}prestashop>oct8ne_45e37dc42e288221084fc298cd93c8bb'] = 'Su contraseña...';
$_MODULE['<{oct8ne}prestashop>oct8ne_98045f7a4e566c2167bac30218c338ac'] = 'Deberás rellenar los campos con los datos de tu usuario del panel de administración de Oct8ne. Si todavía no tienes un usuario de Oct8ne puedes crearlo';
$_MODULE['<{oct8ne}prestashop>oct8ne_6c92285fa6d3e827b198d120ea3ac674'] = 'aquí';
$_MODULE['<{oct8ne}prestashop>oct8ne_99dea78007133396a7b8ed70578ac6ae'] = 'Iniciar sesión';
$_MODULE['<{oct8ne}prestashop>oct8ne_87e9c089875dbf587734df396ce7423a'] = 'Base de Prestashop';
$_MODULE['<{oct8ne}prestashop>oct8ne_c5f3a5606a802e944c16fb93ac747557'] = 'Buscador Empathybroker';
$_MODULE['<{oct8ne}prestashop>oct8ne_afaa5ee5fcca30cc8ab8b7b8096d76b8'] = 'Doofinder';
$_MODULE['<{oct8ne}prestashop>oct8ne_ede9e64250ae298e24874dfe3c23c567'] = 'Motor de búsqueda de Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_14e69b495b4ad97a1c4a468d99169b21'] = 'Motor';
$_MODULE['<{oct8ne}prestashop>oct8ne_daa6b483e9f6ca081ec7e0b4a352f9e9'] = 'Guardar';
$_MODULE['<{oct8ne}prestashop>oct8ne_dcd1a7260fe3e11d54d0f8d6e17dee37'] = 'URL API';
$_MODULE['<{oct8ne}prestashop>oct8ne_d2cb1b13319e5118823778f3e4505f41'] = 'Información de oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_8d1bd3e5756e3454644c531701ff73e0'] = 'Usuario Activo';
$_MODULE['<{oct8ne}prestashop>oct8ne_0323de4f66a1700e2173e9bcdce02715'] = 'Cerrar sesión';
$_MODULE['<{oct8ne}prestashop>oct8ne_7075e53a2135d5c3d687fd5a6966e24d'] = 'En el encabezado de página';
$_MODULE['<{oct8ne}prestashop>oct8ne_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'En pie de página';
$_MODULE['<{oct8ne}prestashop>oct8ne_eb6d8ae6f20283755b339c0dc273988b'] = 'Estándar';
$_MODULE['<{oct8ne}prestashop>oct8ne_3168ca6855e90fdc6ef9a9022b747df3'] = 'Opciones';
$_MODULE['<{oct8ne}prestashop>oct8ne_031cf59f5628f2828e2433d82aa26c7a'] = 'Puede elegir donde cargar los scripts de oct8ne: En el footer o en el header de su página';
$_MODULE['<{oct8ne}prestashop>oct8ne_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posición';
$_MODULE['<{oct8ne}prestashop>oct8ne_1c8d7e5020585439fe9972e6288b3687'] = 'Tipo de de Imagenes';
$_MODULE['<{oct8ne}prestashop>oct8ne_a743c9120ecd8b14ccf16ed8d12a68d9'] = 'Tipo 1 añade el id del producto por delante de la id de la imagen. Útil en casos específicos. Cuidado, modifica esta opción sólo si es necesario';
$_MODULE['<{oct8ne}prestashop>oct8ne_8118930728828251951b4e70fbab5216'] = 'Filtro detalles del pedido';
$_MODULE['<{oct8ne}prestashop>oct8ne_1e42eb1237081fbcf80f9ea8faa6b12a'] = 'Escribe el nombre de la columna de base de datos desde la que obtener los detalles de un pedido';
$_MODULE['<{oct8ne}prestashop>oct8ne_538caaeb4a6fe05af1ca371deef849c4'] = '**Si elige \"Llamada de script\", debe llamar a la función insertOct8ne(); siempre que desee cargar el código de Oct8ne en la página.**';
$_MODULE['<{oct8ne}prestashop>oct8ne_773dd3941accb46e3c52545d727b6339'] = 'Retrasar la carga de Oct8ne hasta la interacción del usuario';
$_MODULE['<{oct8ne}prestashop>oct8ne_164b3389d131993789ac5b16193392bf'] = '\'), \'label\' => $this->l(\'Retraso en la carga de Oct8ne en la página (segundos):';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_af1b98adf7f686b84cd0b443e022b7a0'] = 'Categorías';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_2377be3c2ad9b435ba277a73f0f1ca76'] = 'Marcas';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_27ce7f8b5623b2e2df568d64cf051607'] = 'Stock';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_bafd7322c6e97d25b6299b5d6fe8920b'] = 'No';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_93cba07454f06a4a960172bbd6e2a435'] = 'Si';
$_MODULE['<{oct8ne}prestashop>update_notification_af02b06496e83946e73e69d774782654'] = '¡Nueva versión disponible!';
$_MODULE['<{oct8ne}prestashop>update_notification_9ccf7c27af233aba9769f025f5086828'] = 'Tienes la versión';
$_MODULE['<{oct8ne}prestashop>update_notification_34b6cd75171affba6957e308dcbd92be'] = 'La versión';
$_MODULE['<{oct8ne}prestashop>update_notification_fced98409ccd0902ca6784b69912d880'] = 'esta disponible.';
$_MODULE['<{oct8ne}prestashop>update_notification_6ed176ceb621143b7a4cf41b4a91b9f4'] = 'Descargar v';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0d07cb35250063972daeb65e388ee3d'] = 'Configuración básica - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posición';
$_MODULE['<{oct8ne}prestashop>customerconfig_7075e53a2135d5c3d687fd5a6966e24d'] = 'Header';
$_MODULE['<{oct8ne}prestashop>customerconfig_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'Footer';
$_MODULE['<{oct8ne}prestashop>customerconfig_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Puede elegir dónde cargar los scripts oct8ne: en el pie de página o en el encabezado de su página';
$_MODULE['<{oct8ne}prestashop>customerconfig_3284614a26b9eebe62398c0174743691'] = 'Tipo de imagen';
$_MODULE['<{oct8ne}prestashop>customerconfig_0663eabe90a1e1578e1a090d82f6d89d'] = 'Estándar';
$_MODULE['<{oct8ne}prestashop>customerconfig_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Tipo 1';
$_MODULE['<{oct8ne}prestashop>customerconfig_2141d9976decee64d296a8c3146ab839'] = 'Tipo 1 agrega la ID del producto delante del ID de la imagen. Útil en casos específicos. Precaución, modifique esta opción solo si es necesario';
$_MODULE['<{oct8ne}prestashop>customerconfig_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0cc842d01c1807510e37fe22f4d2d67'] = 'Motor de búsqueda - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_7bfa30721c5e726ff17e3f972237a82c'] = 'Motor';
$_MODULE['<{oct8ne}prestashop>customerconfig_935565d6f7077f17422708654b138b47'] = 'Motor de búsqueda a usar';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0d07cb35250063972daeb65e388ee3d'] = 'Configuración básica - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posición';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7075e53a2135d5c3d687fd5a6966e24d'] = 'Header';
$_MODULE['<{oct8ne}prestashop>customerconfig7_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'Footer';
$_MODULE['<{oct8ne}prestashop>customerconfig7_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Puede elegir dónde cargar los scripts oct8ne: en el pie de página o en el encabezado de su página';
$_MODULE['<{oct8ne}prestashop>customerconfig7_3284614a26b9eebe62398c0174743691'] = 'Tipo de imagen';
$_MODULE['<{oct8ne}prestashop>customerconfig7_0663eabe90a1e1578e1a090d82f6d89d'] = 'Estándar';
$_MODULE['<{oct8ne}prestashop>customerconfig7_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Tipo 1';
$_MODULE['<{oct8ne}prestashop>customerconfig7_2141d9976decee64d296a8c3146ab839'] = 'Tipo 1 agrega la ID del producto delante del ID de la imagen. Útil en casos específicos. Precaución, modifique esta opción solo si es necesario';
$_MODULE['<{oct8ne}prestashop>customerconfig7_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0cc842d01c1807510e37fe22f4d2d67'] = 'Motor de búsqueda - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7bfa30721c5e726ff17e3f972237a82c'] = 'Motor';
$_MODULE['<{oct8ne}prestashop>customerconfig7_935565d6f7077f17422708654b138b47'] = 'Motor de búsqueda a usar';

==> oct8ne-v.1.3.3.zip: oct8ne/translations/es.php <==
<?php

global $_MODULE;
$_MODULE = [];
$_MODULE['<{oct8ne}prestashop>oct8ne_bc741b828f1fc35a6f10c870d6056343'] = 'Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_8ff7439dd2ee3184597be0c738ad566a'] = 'Conector del módulo Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_a9390206b02d5d06ee405aa6b4d7b232'] = 'Todos los datos se borrarán ¿Desea continuar?';
$_MODULE['<{oct8ne}prestashop>oct8ne_004b04925fa8a42d0d28c3862c6947bd'] = 'Identificación incorrecta, por favor, comprueba tus credenciales';
$_MODULE['<{oct8ne}prestashop>oct8ne_5f2faa4c7bc8b0d9862218f744a1aee3'] = 'Configuración de oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{oct8ne}prestashop>oct8ne_3d236caa22b35b852d3d9f402ecd361d'] = 'Su email...';
$_MODULE['<{oct8ne}prestashop>oct8ne_dc647eb65e6711e155375218212b3964'] = 'Contraseña';
$_MODULE['<{oct8ne}prestashop>oct8ne_45e37dc42e288221084fc298cd93c8bb'] = 'Su contraseña...';
$_MODULE['<{oct8ne}prestashop>oct8ne_98045f7a4e566c2167bac30218c338ac'] = 'Deberás rellenar los campos con los datos de tu usuario del panel de administración de Oct8ne. Si todavía no tienes un usuario de Oct8ne puedes crearlo';
$_MODULE['<{oct8ne}prestashop>oct8ne_6c92285fa6d3e827b198d120ea3ac674'] = 'aquí';
$_MODULE['<{oct8ne}prestashop>oct8ne_99dea78007133396a7b8ed70578ac6ae'] = 'Iniciar sesión';
$_MODULE['<{oct8ne}prestashop>oct8ne_87e9c089875dbf587734df396ce7423a'] = 'Base de Prestashop';
$_MODULE['<{oct8ne}prestashop>oct8ne_c5f3a5606a802e944c16fb93ac747557'] = 'Buscador Empathybroker';
$_MODULE['<{oct8ne}prestashop>oct8ne_afaa5ee5fcca30cc8ab8b7b8096d76b8'] = 'Doofinder';
$_MODULE['<{oct8ne}prestashop>oct8ne_ede9e64250ae298e24874dfe3c23c567'] = 'Motor de búsqueda de Oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_14e69b495b4ad97a1c4a468d99169b21'] = 'Motor';
$_MODULE['<{oct8ne}prestashop>oct8ne_dcd1a7260fe3e11d54d0f8d6e17dee37'] = 'URL API';
$_MODULE['<{oct8ne}prestashop>oct8ne_daa6b483e9f6ca081ec7e0b4a352f9e9'] = 'Guardar';
$_MODULE['<{oct8ne}prestashop>oct8ne_d2cb1b13319e5118823778f3e4505f41'] = 'Información de oct8ne';
$_MODULE['<{oct8ne}prestashop>oct8ne_8d1bd3e5756e3454644c531701ff73e0'] = 'Usuario Activo';
$_MODULE['<{oct8ne}prestashop>oct8ne_0323de4f66a1700e2173e9bcdce02715'] = 'Cerrar sesión';
$_MODULE['<{oct8ne}prestashop>oct8ne_3168ca6855e90fdc6ef9a9022b747df3'] = 'Opciones';
$_MODULE['<{oct8ne}prestashop>oct8ne_031cf59f5628f2828e2433d82aa26c7a'] = 'Puede elegir donde cargar los scripts de oct8ne: En el footer o en el header de su página';
$_MODULE['<{oct8ne}prestashop>oct8ne_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posición';
$_MODULE['<{oct8ne}prestashop>oct8ne_1c8d7e5020585439fe9972e6288b3687'] = 'Tipo de de Imagenes';
$_MODULE['<{oct8ne}prestashop>oct8ne_a743c9120ecd8b14ccf16ed8d12a68d9'] = 'Tipo 1 añade el id del producto por delante de la id de la imagen. Útil en casos específicos. Cuidado, modifica esta opción sólo si es necesario';
$_MODULE['<{oct8ne}prestashop>oct8ne_8118930728828251951b4e70fbab5216'] = 'Filtro detalles del pedido';
$_MODULE['<{oct8ne}prestashop>oct8ne_1e42eb1237081fbcf80f9ea8faa6b12a'] = 'Escribe el nombre de la columna de base de datos desde la que obtener los detalles de un pedido';
$_MODULE['<{oct8ne}prestashop>oct8ne_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_af1b98adf7f686b84cd0b443e022b7a0'] = 'Categorías';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_2377be3c2ad9b435ba277a73f0f1ca76'] = 'Marcas';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_27ce7f8b5623b2e2df568d64cf051607'] = 'Stock';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_bafd7322c6e97d25b6299b5d6fe8920b'] = 'No';
$_MODULE['<{oct8ne}prestashop>oct8neconnector_93cba07454f06a4a960172bbd6e2a435'] = 'Si';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0d07cb35250063972daeb65e388ee3d'] = 'Configuración básica - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posición';
$_MODULE['<{oct8ne}prestashop>customerconfig_7075e53a2135d5c3d687fd5a6966e24d'] = 'Header';
$_MODULE['<{oct8ne}prestashop>customerconfig_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'Footer';
$_MODULE['<{oct8ne}prestashop>customerconfig_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Puede elegir dónde cargar los scripts oct8ne: en el pie de página o en el encabezado de su página';
$_MODULE['<{oct8ne}prestashop>customerconfig_3284614a26b9eebe62398c0174743691'] = 'Tipo de imagen';
$_MODULE['<{oct8ne}prestashop>customerconfig_0663eabe90a1e1578e1a090d82f6d89d'] = 'Estándar';
$_MODULE['<{oct8ne}prestashop>customerconfig_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Tipo 1';
$_MODULE['<{oct8ne}prestashop>customerconfig_2141d9976decee64d296a8c3146ab839'] = 'Tipo 1 agrega la ID del producto delante del ID de la imagen. Útil en casos específicos. Precaución, modifique esta opción solo si es necesario';
$_MODULE['<{oct8ne}prestashop>customerconfig_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{oct8ne}prestashop>customerconfig_b0cc842d01c1807510e37fe22f4d2d67'] = 'Motor de búsqueda - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig_7bfa30721c5e726ff17e3f972237a82c'] = 'Motor';
$_MODULE['<{oct8ne}prestashop>customerconfig_935565d6f7077f17422708654b138b47'] = 'Motor de búsqueda a usar';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0d07cb35250063972daeb65e388ee3d'] = 'Configuración básica - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_52f5e0bc3859bc5f5e25130b6c7e8881'] = 'Posición';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7075e53a2135d5c3d687fd5a6966e24d'] = 'Header';
$_MODULE['<{oct8ne}prestashop>customerconfig7_d8b79cfcb17f0db448fb9f3a6ecf36ce'] = 'Footer';
$_MODULE['<{oct8ne}prestashop>customerconfig7_8ef23b176e99d7facd4f2ad8619a5fd4'] = 'Puede elegir dónde cargar los scripts oct8ne: en el pie de página o en el encabezado de su página';
$_MODULE['<{oct8ne}prestashop>customerconfig7_3284614a26b9eebe62398c0174743691'] = 'Tipo de imagen';
$_MODULE['<{oct8ne}prestashop>customerconfig7_0663eabe90a1e1578e1a090d82f6d89d'] = 'Estándar';
$_MODULE['<{oct8ne}prestashop>customerconfig7_a5cd0f7fdebcf2afe5c34be8366eb329'] = 'Tipo 1';
$_MODULE['<{oct8ne}prestashop>customerconfig7_2141d9976decee64d296a8c3146ab839'] = 'Tipo 1 agrega la ID del producto delante del ID de la imagen. Útil en casos específicos. Precaución, modifique esta opción solo si es necesario';
$_MODULE['<{oct8ne}prestashop>customerconfig7_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{oct8ne}prestashop>customerconfig7_b0cc842d01c1807510e37fe22f4d2d67'] = 'Motor de búsqueda - Oct8ne';
$_MODULE['<{oct8ne}prestashop>customerconfig7_7bfa30721c5e726ff17e3f972237a82c'] = 'Motor';
$_MODULE['<{oct8ne}prestashop>customerconfig7_935565d6f7077f17422708654b138b47'] = 'Motor de búsqueda a usar';
